/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "Age.h"
#include "log.h"

int Age::min_ = 0;
int Age::max_ = 0;

// supply the definition of static member age_strings
char* Age::age_strings_[NAgeStrings] = {
    "Age 0",
    "Age 1",
    "Age 2",
    "Age 3",
    "Age 4",
    "Age 5",
    "Age 6",
    "Age 7",
    "Age 8"
};

    // converts age enum to corresponding string
char* Age::string()
{ 
    int index = age_-bottom();
    if (index < 0 || index >= NAgeStrings)
        return "(unknown)";
    else
        return age_strings_[index]; 
}

void Age::config(int min, int max)
{ 
    min_ = min; 
    max_ = max;

    Age tmp; 
    tmp.check(); 
}

// parser called fn to increase max
void Age::increaseMax(int max)
{ 
    if (max > max_) {
        max_ = max; 
        Age tmp; 
        tmp.check(); 
    }
}

// sanity check
void Age::check() const
{
    if (age_ < min_ || age_ > max_ ) {

        LogMsg(L_Fatal, "invalid age specification or configuration.\n");
    }
}
