/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// CNR_HarvestRatioMultipleEncounter.h  -  CNR derived class

#ifndef CNR_HarvestRatioMultipleEncounter_H
#define CNR_HarvestRatioMultipleEncounter_H

#include "CNR.h"

class CNR_HarvestRatioMultipleEncounter : public CNR_HarvestRatio {
  public:
    CNR_HarvestRatioMultipleEncounter(double legalSel, double sublegalSel, 
                                      double legalReleaseMortRate, double baseSeason,
                                      double recaptureInterval) 
        : CNR_HarvestRatio(legalSel, sublegalSel), legalReleaseMortRate_(legalReleaseMortRate),
        baseEncounterPeriods_(recaptureInterval ? (baseSeason/recaptureInterval) : baseSeason)
    {}

    virtual double sublegalMort(const HvMort*) const;
    virtual double legalMort(const HvMort*) const;

  protected:
    // sublegal ratio is same as parent class, but legals are customized
    virtual double legal_ratio(const Fishery& f, const Region& r) const;

    // utility fn for computing the cnr scalar
    virtual double cnrMultiEncScalar(const HvMort*) const;
    
    double legalReleaseMortRate_;
    double baseEncounterPeriods_;
};    
    

#endif // CNR_HarvestRatioMultipleEncounter_H
