/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// DataRequestState.h - State derived class which holds all variable state information 
// resident in the DataRequestManager

#ifndef DataRequestState_H
#define DataRequestState_H

#include "State.h"
#include <rw/tpslist.h>


// DataRequestState takes and restores snapshots of the current state of the DataRequestManager.  
// since the DRM maintains a list of DataRequestObjects, this is implemented by having this
// state class hold a list of derived class State objects, one each for each of the DataRequests
// currently in the DRM.  

class DataRequestState : public State {
  public:
      DataRequestState();
      virtual ~DataRequestState();

    virtual void restoreState() const;      // restore cohort state to stored value

  protected:
    virtual void saveState();               // take a snapshot of current cohort state

  private:
    friend class DataRequestManager;        // the DataRequestManager writes the state vars

    RWTPtrSlist<State> stateComponents_;    // one for each Request currently in the manager
};


#endif // DataRequestState_H