/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// DefaultCohortGenerator.cpp

#include "DefaultCohortGenerator.h"
#include "CohortManager.h"
#include "Stock.h"

void DefaultCohortGenerator::
newAge0Cohorts(double abd, unsigned region, const Stock* stock, unsigned broodyear)
{
    if (abd > 0.0) {
        // this CohortGenerator uses cohorts with default characteristics.
        // if there is already an existing active cohort for this stock and brood year, 
        // find it and use it.
        CohortID id(stock, broodyear);
        Cohort* cohort = CohortManager::findActiveCohort(id);
        if (!cohort) {
            // make a new active cohort if necessary
            cohort = CohortManager::newActiveCohort(id);
        }
        cohort->abundance(region) += abd;
    }
}
