/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef FisheryArray_H
#define FisheryArray_H

#include "GenericArray.h"
#include "Array1D.h"

// a generic array subclass which provides for a single dimensional
// array indexed by timestep.

template <class T>
class FisheryArray : public GenericArray<T> {
  public:
    FisheryArray(size_t nFisheries)
	: nFisheries_(nFisheries), array_(nFisheries)
    {}

    FisheryArray(size_t nFisheries, const T& dfltVal);

    // generic interface
    virtual const T& operator[](const GenericArrayIndex& id) const
    { return array_[id.fisheryIndex]; }

    virtual T& operator[](const GenericArrayIndex& id)
    { return array_[id.fisheryIndex]; }

    virtual void newGenericIndexList(RWTPtrOrderedVector<GenericArrayIndex>& list) const;

  private:
    size_t nFisheries_;

    Array1D<T> array_;
};

#include <rw/compiler.h>
#ifdef RW_COMPILE_INSTANTIATE
#include "FisheryArray.cpp"
#endif /* compile time instantiation */

#endif // FisheryArray_H
