/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// FisheryManager.h - manage fisheries and overall policy information

#ifndef FisheryManager_H
#define FisheryManager_H

#include "auto_ptr.h"
#include "FisheryRegionYearTimeArray.h"

class FisheryPolicy;
class FisheryUnit;

// a PolicyTable is indexed by fishery, region, year, and timestep
typedef FisheryRegionYearTimeArray< auto_ptr<FisheryPolicy> > PolicyTable;

class FisheryManager {
  public:
    // config must be called to establish the storage for the PolicyTable.
    // fisheries, regions, years, and times must already be configured.
    static void config();
    static void cleanup() { policyTable_.release(); }

    static void takeHarvests();

    // insert a policy into the table
    static void insertPolicy(auto_ptr<FisheryPolicy>, const GenericArrayIndex&);

    // find and return a FisheryPolicy for a given FisheryUnit
    static FisheryPolicy* findPolicy(FisheryUnit*);

    // return a particular effort scalar
    static double effortScalar(const GenericArrayIndex& gendex);

    // append GenericIDs for the PolicyTable to the supplied list
    static void newPolicyTableIndexList(RWTPtrOrderedVector<GenericArrayIndex>& list)
    { policyTable_->newGenericIndexList(list); }

  private:
    static auto_ptr<PolicyTable> policyTable_;
};

#endif // FisheryManager_H
