/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "FisheryScheduleParser.h"
#include "FisheryTokens.h"

#include "globals.h"
#include "Fishery.h"
#include "FisheryRegionYearTimeArray.h"


// ctor utility fns
void
FisheryScheduleParser::initKeymap()
{
    keymap_.insert(FisheryTokens::ACTIVE, active);
    initGenArrayKeymap(keymap_);
}

void
FisheryScheduleParser::initState()
{
    // configure the initial state with the correct id list.
    State* state = new State;
    state->context = "FisherySchedule data";
    configParser(state);
    stateStack.push(state);
}

FisheryScheduleParser::FisheryScheduleParser(Parser& p)
    : GenArrayParser(p)
{
    initState();
    initKeymap();
}

// create generic array indices for schedule data.  this is accomplished
// by making a temporary array of FisheryXRegionXYearXTime, and generating
// the ids from it.

void
FisheryScheduleParser::configParser(State* state)
{
    GenericArrayIndex size;
    size.resetToSizes();
    FisheryRegionYearTimeArray<char> genarray(size.fisheryIndex, size.regionIndex, size.yearIndex,
                                         size.timeIndex);
    genarray.newGenericIndexList(state->ids); // create the proper list of generic ids

    // if we are explicitly scheduling via this parser, then the default for all fisheries
    // is for the schedule to be "off", which is handled at this time
    for (int i=0; i < ::Fisheries.num(); ++i) {
        Fisheries[i].clearSchedule();
    }
}


// activate fisheries in every year/timestep/region as indicated by the generic
// id list
void
FisheryScheduleParser::active()
{
    // iterate through the ids in the current state
    RWTPtrOrderedVector<GenericArrayIndex>::iterator iter = (stateStack.top()->ids).begin();
    while (iter != (stateStack.top()->ids).end()) {
        GenericArrayIndex& id = **iter;
        Fisheries[id.fisheryIndex].activate(id.yearIndex, id.timeIndex, id.regionIndex);
        ++iter;
    }
    // pop one level of state after processing the data
    parseEnd();
}
