/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef FisheryYearArray_H
#define FisheryYearArray_H

#include "GenericArray.h"
#include "Chronograph.h"
#include "Array2D.h"

// a generic array subclass which provides for a two dimensional
// array indexed by fishery and year.

template <class T>
class FisheryYearArray : public GenericArray<T> {
  public:
    FisheryYearArray(size_t nFisheries, size_t nYears)
	: nFisheries_(nFisheries), nYears_(nYears),
	  array_(nFisheries, nYears)
    {}

    FisheryYearArray(size_t nFisheries, size_t nYears, const T&dfltVal);

    // generic interface
    virtual const T& operator[](const GenericArrayIndex& id) const
    { return array_[id.fisheryIndex]
                   [id.yearIndex]; }

    virtual T& operator[](const GenericArrayIndex& id)
    { return array_[id.fisheryIndex]
	  	   [id.yearIndex]; }

    virtual void newGenericIndexList(RWTPtrOrderedVector<GenericArrayIndex>& list) const;

  private:
    size_t nFisheries_;
    size_t nYears_;

    Array2D<T> array_;
};

#include <rw/compiler.h>
#ifdef RW_COMPILE_INSTANTIATE
#include "FisheryYearArray.cpp"
#endif /* compile time instantiation */

#endif // FisheryYearArray_H
