/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef GenericDefaultArray_H
#define GenericDefaultArray_H

#include "GenericArray.h"
#include <rw/tpslist.h>

// a generic array subclass which provides for a single value.
// useful as a default when a more detailed table is not present.

template <class T>
class GenericDefaultArray : public GenericArray<T> {
  public:
    GenericDefaultArray()
    {}

    GenericDefaultArray(const T& dfltVal) : value_(dfltVal)
    {}

    // generic interface
    virtual const T& operator[](const GenericArrayIndex& id) const
    { return value_; }

    virtual T& operator[](const GenericArrayIndex& id)
    { return value_; }

    virtual void newGenericIndexList(RWTPtrOrderedVector<GenericArrayIndex>& list) const
    { GenericArrayIndex* id = new GenericArrayIndex(); list.append(id); }

  private:
    T value_;
};

#endif // GenericDefaultArray_H
