/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// Historian.cpp

#include "Historian.h"
#include "DataRequestManager.h"
#include "TrackDetailedFisheryCatches.h"
#include "Chronograph.h"
#include "Fisheries.h"
#include "SystemClock.h"

TrackDetailedFisheryCatches* Historian::fisheryCatches_ = 0;

// set up the various DataRequest objects necessary to record the desired data
void Historian::init()
{
    // old pointers are owned by the DataRequestManager, and are simply ignored here
    fisheryCatches_ = new TrackDetailedFisheryCatches();
    fisheryCatches_->config();
    DataRequestManager::schedule(fisheryCatches_);
}

// base period average for a specific region and time
double Historian::
basePeriodAverageCatch(const Fishery* fishery, int region, int time, int baseStartYearIndex, 
                       int baseEndYearIndex)
{
    return fisheryCatches_->basePeriodAverageCatch(fishery, region, time, baseStartYearIndex, baseEndYearIndex);
}

// base period average for total catch in a year
double Historian::
basePeriodTotalAverageCatch(const Fishery* fishery, int baseStartYearIndex, int baseEndYearIndex)
{
    double total = 0;
    for (int time=0; time < Chronograph::nTimeSteps(); ++time) {
        for (int region=0; region < Geographer::nRegions(); ++region) {
            total += fisheryCatches_->basePeriodAverageCatch(fishery, region, time, 
                                                             baseStartYearIndex, baseEndYearIndex);
        }
    }
    return total;
}

double Historian::
totalCatch(const Fishery* fishery, const TimeStamp& first, const TimeStamp& last)
{
    return fisheryCatches_->totalCatch(fishery, first, last);
}
