/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// HvMort.cpp

#include "Fishery.h"
#include "Region.h"
#include "Cohort.h"
#include "Stock.h"
#include "HarvestProcess.h"
#include "HvMort.h"
#include "NonNeg.h"
#include "HarvestManager.h"
#include "CNR.h"
#include "GenericArray.h"
#include "SystemClock.h"

//#include <math.h>

// zero the contents of this hvmort
void HvMort::zero()
{
    legalCatch_ = 0.0;
    shakers_ = 0.0;
    dropOffs_ = 0.0;
    cnrSublegal_ = 0.0;
    cnrLegal_ = 0.0;
}

// compute a harvest in the current timestep
void HvMort::harvest(double policyScalar)
{
    legalCatch_ = harvestProcess_->computeCatch(*this, policyScalar);
}

// cohort abundance corresponding to this harvest
double HvMort::cohortAbundance() const
{
    return cohort_.abundance(region_);
}

// set the cnr mortalities
void HvMort::setCNR()
{
    GenericArrayIndex gendex(&cohort_, fishery_.index(), region_.index(), *::SystemClock);
    const CNR* cnr = HarvestManager::cnr(gendex);
    if (cnr) {
        cnrSublegal_ = cnr->sublegalMort(this);
        cnrLegal_ = cnr->legalMort(this);
    }
    else {
        cnrSublegal_ = 0;
        cnrLegal_ = 0;
    }
}

// update cohort abundances
void HvMort::applyHarvestMorts()
{
    // this routine casts away const to update the cohort abundance.
    // perhaps not the best approach, but certainly most convenient...

    Cohort& cohort = const_cast<Cohort&> (cohort_);
    cohort.abundance(region_) = NonNeg(cohort_.abundance(region_) 
        - (legalCatch_ + shakers_ + dropOffs_ + cnrSublegal_ + cnrLegal_));
}
