/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef KeywordProcessor_H
#define KeywordProcessor_H

// The KeywordProcessor template class works closely with a class P
// derived from the Parser class, which is supplied as the template
// class specifier.  Its purpose is to maintain a map of keyword
// tokens and their corresponding member functions for processing.
// The map is set up (typically in P's ctor) with calls to insert().
// The real work is done by the processKeyword() fn, which looks up
// the requested token in the keyword map and calls the proper member
// fn.  ParseError exceptions are either handled (and output) here, or
// rethrown.  This class must also be made a friend of the derived
// Parser class it works with, in order to call the target member fns.

#include "pragma.h"

#include <rw/tvhdict.h>
#include <rw/cstring.h>
#include "ParseError.h"


//RW_SL_STD_USING  // to bring in stdlib namespace when needed
#if !defined(RW_NO_STL) && !defined(RW_NO_STD_NAMESPACE)   
  using namespace std;                                                              
#endif

template <class T>
class KeywordProcessor {
  public:
    typedef void (T::*PMFn)();

    KeywordProcessor() : keymap_() {}
    
    void processKeyword(T& parser, RWCString) const;

    void insert(const RWCString& key, PMFn fn)
    { keymap_.insertKeyAndValue(key, fn); }

  private:
      class HashFn {
      public:
          unsigned long operator() (const RWCString& str) const
          { return str.hash(); }
      };

    RWTValHashMap<RWCString, PMFn, HashFn, equal_to<RWCString> > keymap_;

};

#include <rw/compiler.h>
#ifdef RW_COMPILE_INSTANTIATE
#include "KeywordProcessor.cpp"
#endif /* compile time instantiation */

#endif // KeywordProcessor_H
