/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// Maturation class - handles maturation!

#ifndef Maturation_H
#define Maturation_H

#include "RCObject.h"
#include "RCPtr.h"

class GenericArrayIndex;
class Cohort;

// Maturation class.  The maturate() function operates on the passed
// in cohort.  For the region specified in the generic index, a
// mature cohort abundance is calculated using the maturationRate
// value.  The mature cohort corresponding to the given cohort is
// found or created, and the abundance increased by the calculated
// amount.  The immature cohort abundance is also decreased by the
// same amount.

class Maturation : private RCObject {
  public:
    Maturation(double rate) : maturationRate_(rate)
    {}
    
    void maturate(Cohort* cohort, const GenericArrayIndex& id) const;

    double maturationRate() const { return maturationRate_; }
    
  private:
    double maturationRate_;

    friend class RCPtr<Maturation>;
};


#endif // Maturation_H
