/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// Maturation Manager monostate 

#ifndef MaturationManager_H
#define MaturationManager_H

#include <memory>
#include "GenericArray.h"
#include "RCPtr.h"
#include "auto_ptr.h"

class Chronograph;
class Maturation;
typedef GenericArray<RCPtr<Maturation> > MatTable;


// Maturation Manager to handle the maturation of cohorts.  Contains a
// generic array of Maturation objects.  The maturateCohorts() method,
// called in each timestep, accesses each cohort and region,
// extracts the proper Maturation object, and calls its maturate()
// method, passing the cohort and region.

class MaturationManager {
  public:
    MaturationManager() {}
    
    static void maturateCohorts();
    static void config();           // configure with default values
    static void config(auto_ptr<MatTable> newTable);  // configure with a new table
    
    static void insertMaturation(const RCPtr<Maturation>& mat,
				 const GenericArrayIndex& index);

    static double maturationRate(const GenericArrayIndex& index); 

  private:
    friend class MaturationParser;

    // the maturation table
    static auto_ptr<MatTable> matTable_;

    // single instance of a default maturation object
    static const RCPtr<Maturation> defaultMaturation_;
};

#endif // MaturationManager_H
