/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef MaturityTimeArray_H
#define MaturityTimeArray_H

#include "GenericArray.h"
#include "Array2D.h"

// a generic array subclass which provides for an array indexed by
// maturity and timestep.

template <class T>
class MaturityTimeArray : public GenericArray<T> {
  public:
    MaturityTimeArray(size_t nMaturityStates, size_t nSteps)
	: nMaturityStates_(nMaturityStates), nSteps_(nSteps),
	  array_(nMaturityStates, nSteps)
    {}
    
    MaturityTimeArray(size_t nMaturityStates, size_t nSteps, const T& dfltVal);

    // generic interface
    virtual const T& operator[](const GenericArrayIndex& id) const
    { return array_[id.maturityIndex]
	  	   [id.timeIndex]; }

    virtual T& operator[](const GenericArrayIndex& id)
    { return array_[id.maturityIndex]
	  	   [id.timeIndex]; }

    virtual void newGenericIndexList(RWTPtrOrderedVector<GenericArrayIndex>& list) const;

  private:
    size_t nMaturityStates_;
    size_t nSteps_;

    Array2D<T> array_;
};

#include <rw/compiler.h>
#ifdef RW_COMPILE_INSTANTIATE
#include "MaturityTimeArray.cpp"
#endif /* compile time instantiation */

#endif // MaturityTimeArray_H
