/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// MultiCeilingScalarPolicyControl.h - Class which provides overall control
// for ceiling policy management.

#ifndef MultiCeilingScalarPolicyControl_H
#define MultiCeilingScalarPolicyControl_H

#include "pragma.h"

#include <rw/tvordvec.h>
#include <rw/tvvector.h>
#include "Chronograph.h"
#include "PolicyControl.h"
#include "CeilingScalarPolicyControl.h"


//class TrackDetailedFisheryCatches;
class Fishery;

// MultiCeilingScalarPolicyControl class - sets up the objects which
// enforce quotas in fisheries while maintaining constant effort
// scalars over a period of timesteps.  Implemented as a derived class
// of CeilingScalarPolicyControl, and reusing most of the data storage
// and methods provided.  Additionally, beginning and ending timesteps of
// iteration in each year are specified for this class.  Handles creation of
// MultiCeilingIterationControl objects.  At the completion of the
// base period, quota targets are computed using the base period
// catches and the configured quotas.  MultiCeilingIterationControl
// objects are then created and registered with the IterationManager.

class MultiCeilingScalarPolicyControl : public CeilingScalarPolicyControl {
  public:
    MultiCeilingScalarPolicyControl(int basePeriodStart, int basePeriodEnd, int firstStep, int lastStep)
        : CeilingScalarPolicyControl(basePeriodStart, basePeriodEnd),
          firstStep_(firstStep), lastStep_(lastStep)
    {}

    virtual bool valid() const; // confirm that this object is in a valid state

    virtual void createQuotas(const CeilingScalarPolicyControl::CeilingScalarConfig&) const;

  protected:
    // parser is a friend
    friend class CeilingScalarParser;

    int firstStep_;     // first timestep of iteration in each year
    int lastStep_;      // last timestep of iteration in each year
};

#endif // MultiCeilingScalarPolicyControl_H
