/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// OutputEscapementState.h - State derived class which holds all variable state information 
// resident in an OutputPSCStockEscapements object

#ifndef OutputEscapementState_H
#define OutputEscapementState_H

#include "State.h"
#include "OutputPSCStockEscapements.h"
#include "auto_ptr.h"


class OutputEscapementState : public State {
  public:
      OutputEscapementState(OutputPSCStockEscapements* data) 
          : savedState_(new OutputPSCStockEscapements(*data)), originalPtr_(data)
      {}
      virtual ~OutputEscapementState()
      {}

    virtual void restoreState() const;      // restore state to stored value

  protected:
      virtual void saveState() {}           // handled by ctor

  private:
    // this class saves state just by copying the OutputPSCStockEscapements object
    auto_ptr<OutputPSCStockEscapements> savedState_;

    // also save a copy of the original ptr
    OutputPSCStockEscapements* originalPtr_;
};


#endif // OutputEscapementState_H
