/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "OutputFisheryCatches.h"
#include "OutputFisheryState.h"
#include "SystemClock.h"
#include "Fisheries.h"
#include "iotools.h"


// copy ctor makes a deep copy
OutputFisheryCatches::OutputFisheryCatches(const OutputFisheryCatches& rhs)
  :  fname_(rhs.fname_)
{   
    // use the assignment operator for RWGenMat to get a deep copy
    config();
    catches = rhs.catches;
}

// assignment operator also makes deep copy
OutputFisheryCatches& OutputFisheryCatches::
operator=(const OutputFisheryCatches& rhs)
{
    if (this != &rhs) {
        config();
        fname_ = rhs.fname_;
        catches = rhs.catches;
    }
    return *this;
}

void OutputFisheryCatches::
config()
{
    catches.reshape(::Fisheries.num(), Chronograph::nYears());
    clear();
}

void OutputFisheryCatches::
collect(SystemProcesses::ProcessId process)
{
    if (process == SystemProcesses::SP_LastProcess) {
        for (int i=0; i < catches.rows(); ++i) {
            catches(i, Chronograph::currentYearIndex()) += ::Fisheries[i].legalCatch();
        }
    }
}


void OutputFisheryCatches::
output()
{
    FILE *fp = 0;
    
    if (open_outfile(fp, fname_))
        return;  // should probably throw exception here
    
    // write data
    for (int year = 0; year < Chronograph::nYears(); ++year) {
        fprintf(fp, "%d\t", Chronograph::baseYear() + year);
        for (int i = 0; i < catches.rows(); ++i) {
            fprintf(fp, "%.0f\t", catches(i, year));
        }
        fprintf(fp, "\n");
    }
    fclose(fp);
}

State* OutputFisheryCatches::
newSaveState()
{
    return(new OutputFisheryState(this));
}
