/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// OutputFisheryCatches.h - DataRequest object which tracks and outputs
// catches by Fishery and year

#ifndef OutputFisheryCatches_H
#define OutputFisheryCatches_H

#include "pragma.h"

#include <rw/math/genmat.h>
#include <rw/cstring.h>
#include "DataRequest.h"

class OutputFisheryCatches : public DataRequest {
  public:
    OutputFisheryCatches(RWCString fname)
        : fname_(fname)
    { config(); } 

    // copy ctor makes a deep copy
    OutputFisheryCatches(const OutputFisheryCatches&);
    // as does the assignment operator
    OutputFisheryCatches& operator=(const OutputFisheryCatches&);

    virtual void config();
    virtual void collect(SystemProcesses::ProcessId);
    virtual void output();
    virtual void clear() { catches = 0;}
    
    // create a new state object from this object and transfer ownership
    virtual State* newSaveState();

  private:
    RWGenMat<double> catches;
    RWCString fname_;
};


#endif // OutputFisheryCatches_H
