/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// OutputFisheryState.h - State derived class which holds all variable state information 
// resident in an OutputFisheryCatches object

#ifndef OutputFisheryState_H
#define OutputFisheryState_H

#include "State.h"
#include "OutputFisheryCatches.h"
#include "auto_ptr.h"


class OutputFisheryState : public State {
  public:
      OutputFisheryState(OutputFisheryCatches* data) 
          : savedState_(new OutputFisheryCatches(*data)), originalPtr_(data)
      {}
      virtual ~OutputFisheryState()
      {}

      virtual void restoreState() const;      // restore state to stored value

  protected:
      virtual void saveState() {}           // handled by ctor

  private:
    // this class saves state just by copying the OutputFisheryCatches object
    // use auto_ptr to delete old storage
    auto_ptr<OutputFisheryCatches> savedState_;

    // a handle to the original object is also saved
    OutputFisheryCatches* originalPtr_;
};


#endif // OutputFisheryState_H
