/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// PolicyControlManager.cpp

#include "PolicyControlManager.h"

DestructiveTPtrSlist<PolicyControl> PolicyControlManager::controls_;

// add a policy control to the list
void PolicyControlManager::addPolicyControl(auto_ptr<PolicyControl> policyControl)
{
    // the list is destructive, so use the raw pointer
    controls_.insert(policyControl.release());
}


// execute the pre-harvest management method for each policy control
static void preHarvestAction(PolicyControl *pc, void *) 
{ pc->preHarvestManagementAction(); }

void PolicyControlManager::
preHarvestManagement()
{
    controls_.apply(preHarvestAction, 0);
}

// execute the post-harvest management method for each policy control
static void postHarvestAction(PolicyControl *pc, void *) 
{ pc->postHarvestManagementAction(); }

void PolicyControlManager::
postHarvestManagement()
{
    controls_.apply(postHarvestAction, 0);
}
