/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// Production.h - class to handle production of new fish (spawning)

#ifndef Production_H
#define Production_H

#include "pragma.h"

#include <rw/tvordvec.h>
#include "auto_ptr.h"

class ProductionFunction;

// production class handles spawning for one cohort in a region and
// timestep.  the function "double spawn(double escapement)" returns
// the new age0 fish for the given escapement.  it works by keeping a
// list of production functions, and calling each one with the total
// escapement value.  each production function calculates the correct
// number of spawned fish, and the results are added together, then
// returned.

class Production {
  public:
    Production();
    ~Production();

    double spawn(double escapement) const;

    // this class owns the prod fn ptrs, as indicated by the auto_ptr param
    void insertProductionFunction(auto_ptr<const ProductionFunction> prodFn);
    
  private:
    RWTValOrderedVector<auto_ptr<const ProductionFunction> > prodFns_;
};

#endif // Production_H
