/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// ProductionFunction.h - base class for various production functions.
// the main function is spawn() which returns a number of spawned
// fish.  the escapement provided is the total for the cohort in the
// given region/timestep.  it is the responsibility of the production
// function to determine how many of the fish comprising this
// escapement are relevant.

#ifndef ProductionFunction_H
#define ProductionFunction_H

class ProductionFunction {
  public:
    virtual ~ProductionFunction() {}

    virtual double spawn(double escapement) const = 0;

    // allocate storage on the heap and return a new object which is a 
    // copy of the derived class object
    virtual const ProductionFunction* clone() const = 0;
};

#endif // ProductionFunction_H
