/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


/******************************************************************************
*                 Template Class RCPtr (from pp. 203, 206)                    *
*
* (see RCObject.h for comments)
******************************************************************************/

#ifndef RCPTR_H
#define RCPTR_H

template<class T>                      // template class for smart
class RCPtr {                          // pointers-to-T objects; T
  public:                              // must support the RCObject interface
    RCPtr(T* realPtr = 0); 
    RCPtr(const RCPtr& rhs);
    ~RCPtr();
    RCPtr& operator=(const RCPtr& rhs);
    T* operator->() const;
    T& operator*() const;

  private:
    T* pointee;
    void init();
};


template<class T>
void RCPtr<T>::init()
{
    if (pointee == 0) return;

//    if (pointee->isShareable() == false) {
//	pointee = new T(*pointee);
//    }

    pointee->addReference();
}

template<class T>
RCPtr<T>::RCPtr(T* realPtr)
    : pointee(realPtr)
{
    init();
}

template<class T>
RCPtr<T>::RCPtr(const RCPtr& rhs)
    : pointee(rhs.pointee)
{
    init();
}

template<class T>
RCPtr<T>::~RCPtr()
{
    if (pointee)
        if (pointee->removeReference() == 0)
            delete pointee;
}

template<class T>
RCPtr<T>& RCPtr<T>::operator=(const RCPtr& rhs)
{
    if (pointee != rhs.pointee) {
        if (pointee) {
            if (pointee->removeReference() == 0)
                delete pointee;
        }
        pointee = rhs.pointee;
        init();
    }
    
    return *this;
}

template<class T>
T* RCPtr<T>::operator->() const
{
    return pointee;
}

template<class T>
T& RCPtr<T>::operator*() const
{
    return *pointee;
}

#endif // RCPTR_H
