/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// SDS_Cabn.cpp - Standard Data Sentence Cohort Abundance

#include "SDS_Cabn.h"
#include "Chronograph.h"
#include "CohortList.h"
#include "SystemClock.h"
#include "Geographer.h"
#include "Stocks.h"
#include "StandardDataSentenceState.h"

// unique identifier for this sentence type
const char* SDS_Cabn::cabnId_ = "CABN";

SDS_Cabn::SDS_Cabn(ofstream& outfile) : StandardDataSentence(cabnId_, outfile)
{}


void SDS_Cabn::collect(SystemProcesses::ProcessId pid)
{
    // output cohort abundances at the start of each timestep
    if (pid == SystemProcesses::SP_BeforeFirstProcess) {
        for (unsigned region = 0; region < Geographer::nRegions(); ++region) {
            for (unsigned stock=0; stock < ::Stocks.num(); ++stock) {
                CohortList::const_iterator cohortPtr = ::Stocks[stock].getCohorts().begin();
                CohortList::const_iterator endPtr = ::Stocks[stock].getCohorts().end();
                while (cohortPtr != endPtr) {
                    const Cohort* cohort = *cohortPtr;
                    // only output nonzero abundances
                    if (cohort->abundance(region) != 0.0) {
                        static char buf[1024];
/*                        ostrstream s(buf, 1024);
                        s << Chronograph::currentCalendarYear()
                            << ", " << ::SystemClock->currentTimeIndex()+1  // +1 converts to user time
                            << ", " << region+1                             // +1 converts to user regions
                            << ", " << cohort->id().idString()
                            << ", " << cohort->abundance(region)
                            << '\n';
                        buf[s.pcount()] = 0;
*/
                        sprintf(buf, "%d, %d, %d, %s, %.6g\n",
                            Chronograph::currentCalendarYear(),
                            ::SystemClock->currentTimeIndex()+1,  // +1 converts to user time
                            region+1,                             // +1 converts to user regions
                            cohort->id().idString(),
                            cohort->abundance(region)
                            );
                        outputSentence(buf);
                    }
                    ++cohortPtr;
                }
            }
        }
        outfile_.flush();
    }
}

State* SDS_Cabn::
newSaveState()
{
    return (new StandardDataSentenceState(outfile_)); 
}
