/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// Shaker abstract base class, and derived class

#ifndef Shaker_H
#define Shaker_H

class Fishery;
class HvMort;

class Shaker {
  public:
    Shaker()
    {}
    virtual ~Shaker() {};

    // set the shakers and dropoffs for all HvMorts in a Fishery
    virtual void setShakers(Fishery*) const = 0;

    virtual double subLegalShakerMortRate() const = 0;   // just shaker mort rate 
    virtual double dropOffMortRate() const = 0;          // drop off mort rate
    virtual double totalSubLegalCnrMortRate() const = 0; // shaker + drop off mort rates

    // calculate and return dropoffs for a harvest
    virtual double dropOffs(const HvMort* hv) const = 0;
};
   
#endif // Shaker_H
