/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

#include "StandardDataOutputManager.h"
#include "SDS_Cabn.h"
#include "SDS_Fmrt.h"
#include "SDS_Nmrt.h"

#include "DataRequestManager.h"
#include <rw/cstring.h>

// class static vars
ofstream StandardDataOutputManager::output_;
RWCString StandardDataOutputManager::filename_;

// configure a variety of SDS objects, and register them.

void StandardDataOutputManager::config(const RWCString& filename)
{
    filename_ = filename;
}


void StandardDataOutputManager::init()
{
    output_.open(filename_, ios::trunc);

    // the DataRequestManager assumes ownership of these objects upon scheduling
    DataRequest* abn = new SDS_Cabn(output_);
    DataRequest* fmrt = new SDS_Fmrt(output_);
    DataRequest* nmrt = new SDS_Nmrt(output_);
    
    DataRequestManager::schedule(abn);
    DataRequestManager::schedule(fmrt);
    DataRequestManager::schedule(nmrt);
}

