/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// StandardDataOutputManager.h - manager for all StandardDataSentence outputs
// in the system

#ifndef StandardDataOutputManager_H
#define StandardDataOutputManager_H

#include <fstream.h>

class RWCString;

// the StandardDataOutputManager is a monostate responsible for managing the 
// StandardDataSentence (SDS) output of the system.  it takes a filename to which 
// output is to be dumped, opens the file, then creates and registers the 
// individual SDS objects which will perform the output.  

class StandardDataOutputManager {
  public:
    static void config(const RWCString& filename);       // original setup
    static void init();                                  // reinitialize stream
    static void simulationWrapup() { output_.close(); }  // wrapup after every simulation

  private:
    static ofstream output_;
    static RWCString filename_;
};

#endif // StandardDataOutputManager_H