/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// StandardDataSentence.h - base class for outputting data in a strict sentence
//   format.  ctor takes a sentence ID and an open ofstream.  resource management
//   for the ofstream should be handled elsewhere.

#ifndef StandardDataSentence_H
#define StandardDataSentence_H

#include <rw/cstring.h>
#include <fstream.h>

class StandardDataSentence {
  protected:
    // the ofstream should already be open for writing
    StandardDataSentence(const RWCString& id, ofstream& outfile) 
        : id_(id), outfile_(outfile) {}
    
    // standard interface
//    virtual void outputSentence(const RWCString& data)
//    {   outfile_ << id_;
//        if (!data.isNull()) outfile_ << ", " << data; 
//    }
    virtual void outputSentence(const char* data)
    {   outfile_ << id_;
        if (data) outfile_ << ", " << data; 
    }

    // data
    RWCString id_;  // sentence identifier, unique to each derived class
    ofstream& outfile_;
};

#endif // StandardDataSentence_H