/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// SubParser implementations

#include "SubParser.h"

// parsing fn for a subparser.  very similar to the same fn in the
// Parser class, but exits explicitly instead of parsing to the end of
// file.  the behavior is to throw an unexpected EOF if encountered.
// other errors are output as they appear.  fn return is caused
// through manipulation of the forceDone_ flag.

void 
SubParser::parse()
{
    RWCString token;
    while (!forceDone_ && !((token = nextToken()).isNull())) {
        try {
            processKeyword(token);
        }
        catch (ParseError& err) {
            logError(err.errorMessage());
        }
    }

    // If this subparser was started with a file name (e.g. to
    //  process an include command) then hitting the EOF is normal
    //  and expected. Otherwise (e.g. when the subparser was created
    //  to process a language element in an existing file) hitting
    //  the EOF is a dire emergency.
    if (!fromFile_ && token.isNull())
        throw pError(ParseError::Eof, "unexpected EOF");
}

void 
SubParser::parseEndKeyword()
{
    forceDone_ = TRUE;
    nextDataLine();		// skip the rest of this line as comments
}
