/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef TopLevelParser_H
#define TopLevelParser_H

// top level parser.  inherits from Parser to process a whole file.

#include "Parser.h"
#include "KeywordProcessor.h"

class TopLevelParser : public Parser {
  public:
    TopLevelParser(const RWCString& fileName);

  protected:
    virtual void processKeyword(const RWCString& token);

  private:
    void parseInclude();
    void config();

    void transitionMatrix();
    void maturationData();
    void harvestData();
    void fpData();
    void natMortData();
    void pnvData();
	void shakerData();
    void cnrData();
    void ceilingScalars();
    void multiCeilingScalars();
    void ceilingData();
    void cohortData();
    void productionData();
    void fisherySchedule();
    
    friend class KeywordProcessor<TopLevelParser>;
    KeywordProcessor<TopLevelParser> keymap_;
};

#endif // TopLevelParser_H
