/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// TrackDetailedFisheryCatches.h - DataRequest class to keep track of
// catches for all fisheries by year, region and timestep.
// also has a notion of the "base period" and can respond to queries
// based upon that time frame.

#ifndef TrackDetailedFisheryCatches_H
#define TrackDetailedFisheryCatches_H

#include "DataRequest.h"
#include "Chronograph.h"
#include <rw/math/mtharray.h>

class Fishery;


class TrackDetailedFisheryCatches : public DataRequest {
  public:
    TrackDetailedFisheryCatches() 
    {}

    // have copy ctor and assignment op make deep copies
    TrackDetailedFisheryCatches(const TrackDetailedFisheryCatches&);
    TrackDetailedFisheryCatches& operator=(const TrackDetailedFisheryCatches&);

    virtual void config();
    virtual void collect(SystemProcesses::ProcessId);
    virtual void output() {}
    virtual void clear() { catches_ = 0; }

    virtual State* newSaveState(); 

    double basePeriodTotalCatch(const Fishery* fishery, int region, int time,
                                int baseStartYearIndex, int baseEndYearIndex) const;
    double basePeriodAverageCatch(const Fishery* fishery, int region, int time,
                                  int baseStartYearIndex, int baseEndYearIndex) const;
    double totalCatch(const Fishery* fishery, const TimeStamp& first, const TimeStamp& last) const;

  private:
    // track catches by fishery, region, and timestep, and year
    RWMathArray<double> catches_;
};

#endif // TrackDetailedFisheryCatches_H
