/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


/* log.cc
 *
 *	Definition of the non-inline LogLevel class functions, including
 * the construction of all global (reportable) log levels.
 */
#include "log.h"

ofstream LogLevel::logfile;

#ifdef NOT_NEEDED
extern "C"
{
    extern size_t strlen(const char *);
    extern char *strcpy(char *, const char *);
};
#endif



// This is lame and may have to be removed somehow.
char LogBuf[512];	// For log.h, need to define exactly once.  Big enough?

// The usable log levels.  The parameters for construction specify
// flags for the log levels.
LogLevel L_Error(TRUE, "Error", "Error: ", TRUE);
LogLevel L_Warning(TRUE, "Warning", "Warning: ");
LogLevel L_Msg(TRUE, "Messages");
LogLevel L_IOMsg(FALSE, "IO");
LogLevel L_Fatal(TRUE, "Fatal", "FATAL: ", TRUE, FALSE, TRUE);
LogLevel L_Force(TRUE, "Force", "Force: ", TRUE, FALSE);
#ifdef DEBUG
LogLevel L_DbgMsg(TRUE, "Debug");
#else
LogLevel L_DbgMsg(FALSE, "Debug");
#endif

const unsigned LOG_LINES = 16;
const unsigned LOG_WIDTH = 80;
const unsigned LOG_MAX_LINES = 0;	// 0 = no maximum.

/*
 * void LogMsg(const LogLevel &l, const char *format, ...) - Printf style
 *	error message formatting.  Would be nice if this actually ran
 *	inlined.
 */
void LogMsg(const LogLevel &l, const char *format, ...)
{
    if (::LogTest(l)) {
        char* bufptr = LogBuf;
        const char* prefix = l.get_prefix();
        if (prefix) {
            strcpy(bufptr, prefix);
            bufptr += strlen(bufptr);
        }
        va_list args;
        va_start(args, format);
        vsprintf(bufptr, format, args);
        l.display_log_message(LogBuf);
        va_end(args);
    }
    if (l.is_fatal())
        throw(l.get_name());
}

/*
 * LogLevel(Bool set_by_default, char *level_name, char *message_prefix,
 *	Bool force_show, Bool user_can_set, Bool level_is_fatal) -
 *
 */
LogLevel::LogLevel(Bool set_by_default, char *level_name, char *message_prefix,
		   Bool force_show, Bool user_can_set, Bool level_is_fatal)
:flag(set_by_default), user_settable(user_can_set), force(force_show),
 fatal(level_is_fatal), name(level_name), prefix(message_prefix)
{
}

/*
 * LogLevel::~LogLevel()
 */
LogLevel::~LogLevel()
{
}

// initialize the logfile
void LogLevel::config(const char* filename)
{
    if (!logfile.is_open())
        logfile.open(filename, ios::trunc);
}

void LogLevel::cleanup()
{
    logfile.close();
}

/*
 * display_log_message(const char *message) -- Write the message passed in to
 *	the log window.  The varargs part should be in a single string by now.
 */
//void LogLevel::display_log_message(char *message)
void LogLevel::display_log_message(const char *message)
{
    cerr << message;
    if (logfile.good())
        logfile << message;
    return;
}
