/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// VulnerabilityTableParser.h - Vulnerability Table Parser

#ifndef VulnerabilityTableParser_H
#define VulnerabilityTableParser_H

#include "GenArrayParser.h"
#include "VulnerabilityTable.h"

// the vulnerability table parser is a generic array parser

class VulnerabilityTableParser : public GenArrayParser {
  public:
    VulnerabilityTableParser(Parser& p, RWCString dimension);

    // give "copy" of the table to an outside party (reference counting makes it efficient)
    VulnerabilityTable getTable() 
    { return vulnerabilityTable_; }

  protected:
    virtual void processKeyword(const RWCString& token)
    { keymap_.processKeyword(*this, token); }

  private:
    friend class KeywordProcessor<VulnerabilityTableParser>;
    KeywordProcessor<VulnerabilityTableParser> keymap_;
    const RWCString dimension_; // string rep of dimensionality

    virtual void initKeymap();
    virtual void initState();
    void configTable(State* state);

    void vulnerable();
    void invulnerable();

    VulnerabilityTable vulnerabilityTable_;
};

#endif // VulnerabilityTableParser_H
